/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.field.model;

import com.vividsolutions.jts.geom.Envelope;
import com.vividsolutions.jts.geom.Geometry;
import com.vividsolutions.jts.geom.GeometryCollection;
import com.vividsolutions.jts.geom.Point;
import java.awt.Image;
import java.beans.PropertyChangeListener;
import java.util.ArrayList;
import java.util.List;
import nl.cloudfarming.client.geoviewer.Geographical;
import org.geotools.coverage.grid.GridCoverage2D;

/**
 * A class which can be fed a list of shapes From this list of shapes is
 * constructs a geometry collection This collection can be asked for it's
 * centroid
 *
 * @author Merijn Zengers
 */
public class ShapeCollection implements Geographical<GridCoverage2D> {

    private List<Shape> shapes;

    public ShapeCollection(List<Shape> shapes) {
        this.shapes = shapes;
    }

    public ShapeCollection(Shape shape) {
        shapes = new ArrayList<>();
        shapes.add(shape);
    }

    public List<Shape> getShapes() {
        return shapes;
    }

    @Override
    public Point getCentroid() {
        Geometry[] geometries = new Geometry[shapes.size()];
        int counter = 0;
        for (Shape shape : shapes) {
            geometries[counter] = shape.getGeometry();
            counter++;
        }
        GeometryCollection collection = new GeometryCollection(geometries, geometries[0].getFactory());
        return collection.getCentroid();
    }

    @Override
    public Geometry getBoundingBox() {
        Geometry[] geometries = new Geometry[shapes.size()];
        int counter = 0;
        for (Shape shape : shapes) {
            geometries[counter] = shape.getGeometry();
            counter++;
        }
        GeometryCollection collection = new GeometryCollection(geometries, geometries[0].getFactory());
        return collection.getEnvelope();
    }

    @Override
    public GridCoverage2D getRenderObject(Envelope envelope) {
        return null;
    }

    @Override
    public String getTooltipText() {
        return "";
    }

    @Override
    public Image getIcon() {
        return null;
    }

    @Override
    public String getIconLabel() {
        return null;
    }

    @Override
    public void addPropertyChangeListener(PropertyChangeListener listener) {
    }

    @Override
    public void removePropertyChangeListener(PropertyChangeListener listener) {
    }
}
